@@ -113,6 +113,8 @@ from ..responses import (
     RegisterResponse,
     LoginError,
     LoginResponse,
+    LoginInfoResponse,
+    LoginInfoError,
     LogoutError,
     LogoutResponse,
     ProfileGetAvatarResponse,
@@ -172,6 +174,8 @@ from ..responses import (
     ToDeviceResponse,
     UploadError,
     UploadResponse,
+    UpdateDeviceResponse,
+    UpdateDeviceError,
 )
 
 _ShareGroupSessionT = Union[ShareGroupSessionError, ShareGroupSessionResponse]
@@ -788,6 +792,17 @@ class AsyncClient(Client):
 
         return await self._send(RegisterResponse, method, path, data)
 
+    async def login_info(self) -> Union[LoginInfoResponse, LoginInfoError]:
+        """Get the available login methods from the server
+
+        Returns either a `LoginInfoResponse` if the request was successful or
+        a `LoginInfoError` if there was an error with the request.
+
+        """
+        method, path = Api.login_info()
+
+        return await self._send(LoginInfoResponse, method, path)
+
     async def login(
         self,
         password: Optional[str] = None,
@@ -1233,6 +1248,34 @@ class AsyncClient(Client):
 
         return await self._send(DevicesResponse, method, path)
 
+    @logged_in
+    async def update_device(
+            self,
+            device_id: str,
+            content: Dict[str, str]
+    ) -> Union[UpdateDeviceResponse, UpdateDeviceError]:
+        """Update the metadata of the given device.
+
+        Returns either a `UpdateDeviceResponse` if the request was successful or
+        a `UpdateDeviceError` if there was an error with the request.
+
+        Args:
+            device_id (str): The device for which the metadata will be updated.
+            content (Dict[str, str]): A dictionary of metadata values that will be
+                updated for the device.
+
+        Example:
+            >>> device_id = "QBUAZIFURK"
+            >>> content = {"display_name": "My new device"}
+            >>> await client.update_device(device_id, content)
+
+        """
+        method, path, data = Api.update_device(
+            self.access_token, device_id, content
+        )
+
+        return await self._send(UpdateDeviceResponse, method, path, data)
+
     @logged_in
     async def delete_devices(
         self, devices: List[str], auth: Optional[Dict[str, str]] = None
