@@ -64,7 +64,7 @@ def validate_json(instance, schema):
     Validator(schema, format_checker=FormatChecker()).validate(instance)
 
 
-class Schemas(object):
+class Schemas:
     room_message = {
         "type": "object",
         "properties": {
@@ -234,6 +234,16 @@ class Schemas(object):
         "required": ["unsigned"],
     }
 
+    register = {
+        "type": "object",
+        "properties": {
+            "user_id": {"type": "string", "format": "user_id"},
+            "device_id": {"type": "string"},
+            "access_token": {"type": "string"},
+        },
+        "required": ["user_id", "device_id", "access_token"],
+    }
+
     login = {
         "type": "object",
         "properties": {
@@ -1104,6 +1114,38 @@ class Schemas(object):
         "additionalProperties": False,
     }
 
+    m_receipt = {
+        "type": "object",
+        "properties": {
+            "content": {
+                "type": "object",
+                "patternProperties": {
+                    r".*": {
+                        "type": "object",
+                        "properties": {
+                            "m.read": {
+                                "type": "object",
+                                "patternProperties": {
+                                    UserIdRegex: {
+                                        "type": ["object", "string"],
+                                        "properties": {
+                                            "ts": {"type" : "integer"}
+                                        },
+                                        "required": ["ts"]
+                                    }
+                                }
+                            }
+                        }
+                    }
+                }
+            },
+            "type": {"type": "string"},
+            "room_id": {"type": "string"}
+        },
+        "required": ["content", "type"],
+        "additionalProperties": True,
+    }
+
     keys_upload = {
         "type": "object",
         "properties": {
